@@ -22,9 +22,9 @@ class ModelRepository:
 
     def __init__(self):
         self.config = Config.getInstance()
-        self.db_url = self.config.get(DB_URL_KEY)
-        self.db_user = self.config.get(DB_USER_KEY)
-        self.db_pwd = self.config.get(DB_PWD_KEY)
+        self.db_url, _ = self.config.get(DB_URL_KEY)
+        self.db_user, _ = self.config.get(DB_USER_KEY)
+        self.db_pwd, _ = self.config.get(DB_PWD_KEY)
 
         url_parsed = urlparse(self.db_url.replace("jdbc:", ""))
         self.conpool = psycopg2.pool.ThreadedConnectionPool(
