@@ -34,7 +34,11 @@ def handle_error(error):
 
 
 def upload_model(model_name):
-    ModelRepository.getInstance().upload_model(model_name)
+    res, err = ModelRepository.getInstance().upload_model(model_name)
+    if err is None:
+        logging.info(res)
+    else:
+        handle_error(err)
 
 
 def get_model_save_path(model_name):
